@@ -8,7 +8,7 @@ use warnings;
 use Carp;
 use Exporter qw{ import };
 
-our $VERSION = '0.041_01';
+our $VERSION = '0.042_01';
 
 our @EXPORT_OK = qw{ __any };
 
@@ -144,7 +144,8 @@ modules are needed it returns nothing.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org/>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Astro-SIMBAD-Client/issues/>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -152,7 +153,7 @@ Tom Wyant (wyant at cpan dot org)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2020 by Thomas R. Wyant, III
+Copyright (C) 2016-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
